==> sfa-rpc-0.0.9-sources.jar: com/biz/sfa/vo/req/ActivityDistrubutRpcReqVo.java <==
package com.biz.sfa.vo.req;


import java.io.Serializable;
import java.util.List;

/**
 * @author zhangqiang:
 * @version 创建时间：2017年6月27日 下午1:49:56 活动分配接受参数Vo
 */
public class ActivityDistrubutRpcReqVo implements Serializable {

	private static final long serialVersionUID = 7703748625553002088L;
	//登记单号
	private String formNo;
	//标题
	private String title;
	// 经销商编码
	private String dealerCode;
	// 经销商名称
	private String dealerName;
	// 登记岗位编码
	private String registerPosCode;
	// 登记人员
	private String registerFullName;
	// 分配岗位人员信息
	List<DistributionPositionVo> distributionPositionList;
	// 明细信息（一对多）
	List<RegisterDetailVo> registerDetailList;

	public String getFormNo() {
		return formNo;
	}

	public void setFormNo(String formNo) {
		this.formNo = formNo;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getDealerCode() {
		return dealerCode;
	}

	public void setDealerCode(String dealerCode) {
		this.dealerCode = dealerCode;
	}

	public String getDealerName() {
		return dealerName;
	}

	public void setDealerName(String dealerName) {
		this.dealerName = dealerName;
	}

	public String getRegisterPosCode() {
		return registerPosCode;
	}

	public void setRegisterPosCode(String registerPosCode) {
		this.registerPosCode = registerPosCode;
	}

	public String getRegisterFullName() {
		return registerFullName;
	}

	public void setRegisterFullName(String registerFullName) {
		this.registerFullName = registerFullName;
	}

	public List<DistributionPositionVo> getDistributionPositionList() {
		return distributionPositionList;
	}

	public void setDistributionPositionList(List<DistributionPositionVo> distributionPositionList) {
		this.distributionPositionList = distributionPositionList;
	}

	public List<RegisterDetailVo> getRegisterDetailList() {
		return registerDetailList;
	}

	public void setRegisterDetailList(List<RegisterDetailVo> registerDetailList) {
		this.registerDetailList = registerDetailList;
	}

	// //被分配岗位编码
	// private String distributionPosCode;
	//
	// //被分配岗位下人员姓名
	// private String distributionPosName;
	// //分配时间
	// private Timestamp createDate;
	//
	// //执行分配岗位编码
	// private String createPostionCode;
	//
	// //执行分配岗位下人员
	// private String createUser;
	//
	// //人员对应经销商编码
	// private String franchiserCode;
	//
	// //人员对应经销商名称
	// private String franchiserName;

}

==> sfa-rpc-0.0.60-sources.jar: com/biz/sfa/vo/req/ActivityDistrubutRpcReqVo.java <==
package com.biz.sfa.vo.req;


import java.io.Serializable;
import java.util.List;

/**
 * @author zhangqiang:
 * @version 创建时间：2017年6月27日 下午1:49:56 活动分配接受参数Vo
 */
public class ActivityDistrubutRpcReqVo implements Serializable {

	private static final long serialVersionUID = 7703748625553002088L;
	//登记单号
	private String formNo;
	//标题
	private String title;
	// 经销商编码
	private String dealerCode;
	// 经销商名称
	private String dealerName;
	// 登记岗位编码
	private String registerPosCode;
	// 登记人员
	private String registerFullName;
	// 分配岗位人员信息
	List<DistributionPositionVo> distributionPositionList;
	// 明细信息（一对多）
	List<RegisterDetailVo> registerDetailList;
	// 活动类型2级编码
	private String activityTypeCodeSub;
	// 活动类型2级编码名称
	private String activityTypeNameSub;
	// 费用类型编码
	private String costType;
	// 费用类型名称
	private String costTypeName;
	// 是否驳回再申请
	private boolean flag;

	public String getFormNo() {
		return formNo;
	}

	public void setFormNo(String formNo) {
		this.formNo = formNo;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getDealerCode() {
		return dealerCode;
	}

	public void setDealerCode(String dealerCode) {
		this.dealerCode = dealerCode;
	}

	public String getDealerName() {
		return dealerName;
	}

	public void setDealerName(String dealerName) {
		this.dealerName = dealerName;
	}

	public String getRegisterPosCode() {
		return registerPosCode;
	}

	public void setRegisterPosCode(String registerPosCode) {
		this.registerPosCode = registerPosCode;
	}

	public String getRegisterFullName() {
		return registerFullName;
	}

	public void setRegisterFullName(String registerFullName) {
		this.registerFullName = registerFullName;
	}

	public List<DistributionPositionVo> getDistributionPositionList() {
		return distributionPositionList;
	}

	public void setDistributionPositionList(List<DistributionPositionVo> distributionPositionList) {
		this.distributionPositionList = distributionPositionList;
	}

	public List<RegisterDetailVo> getRegisterDetailList() {
		return registerDetailList;
	}

	public void setRegisterDetailList(List<RegisterDetailVo> registerDetailList) {
		this.registerDetailList = registerDetailList;
	}

	public String getActivityTypeCodeSub() {
		return activityTypeCodeSub;
	}

	public void setActivityTypeCodeSub(String activityTypeCodeSub) {
		this.activityTypeCodeSub = activityTypeCodeSub;
	}

	public String getActivityTypeNameSub() {
		return activityTypeNameSub;
	}

	public void setActivityTypeNameSub(String activityTypeNameSub) {
		this.activityTypeNameSub = activityTypeNameSub;
	}

	public String getCostType() {
		return costType;
	}

	public void setCostType(String costType) {
		this.costType = costType;
	}

	public String getCostTypeName() {
		return costTypeName;
	}

	public void setCostTypeName(String costTypeName) {
		this.costTypeName = costTypeName;
	}

	public boolean isFlag() {
		return flag;
	}

	public void setFlag(boolean flag) {
		this.flag = flag;
	}

}
